from typing import Any, Literal, Optional

from .colours.get_logger_colour import get_logger_colour
from .logs.log_args import log_args


def penguin_wrapped_pre_timer(
    func: Any,
    args: Any,
    kwargs: Any,
    verbose: Optional[bool] = False,
    show_args: Optional[bool] = False,
    foreground: Optional[
        Literal["red" "yellow", "green", "blue", "magenta", "cyan", "grey"]
    ] = "grey",
    background: Optional[
        Literal[
            "red" "yellow", "green", "blue", "magenta", "cyan", "grey", "black", "white"
        ]
    ] = "black",
):
    """
    Runs common functions used, and gets the foreground colour, background colour, and the function name to run in the @penguin and @penguin_async decorators.
    """
    func_name = func.__name__
    foreground_colour = get_logger_colour(foreground, "foreground_colours")
    background_colour = get_logger_colour(background, "background_colours")

    if show_args or verbose:
        log_args(args, kwargs, func_name, foreground_colour, background_colour)

    return foreground_colour, background_colour, func_name



import logging
from typing import Any, Optional

from .colours.get_default_colours import get_default_colours

logger = logging.getLogger("penguin")


def penguin_wrapped_post_timer(
    foreground_colour: str,
    background_colour: str,
    func_name: str,
    time_msg: str,
    value: Any,
    verbose: Optional[bool] = False,
    show_return: Optional[bool] = False,
):
    """
    Runs common functions in the @penguin and @penguin_async decorators.
    """
    grey_foreground_colour, black_background_colour = get_default_colours()
    format_start = f"{foreground_colour}{background_colour}"
    format_end = f"{grey_foreground_colour}{black_background_colour}"
    logger.info(
        f"Finished {format_start}{func_name}{format_end} in {format_start}{time_msg}{format_end}"
    )

    if show_return or verbose:
        logger.info(f"Returned value: {format_start}{value!r}{format_end}")

    return



import setuptools
from setuptools import setup

with open("README_PYPI.md", "r") as fh:
    long_description = fh.read()

setup(
    name="penguin_py",
    version="0.2.8",
    description="Penguin: a customizable stopwatch decorator",
    author="espitiaandres",
    url="https://github.com/espitiaandres/penguin",
    long_description=long_description,
    long_description_content_type="text/markdown",
    packages=setuptools.find_packages(),
    keywords=["penguin python", "penguin_py", "stopwatch", "timer", "penguin_py timer"],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Topic :: Utilities",
    ],
    python_requires=">=3.7",
    py_modules=["penguin_py"],
    package_dir={"": "src"},
    install_requires=[
        # Import requirements here
        "pre-commit",
    ],
    download_url="https://github.com/espitiaandres/penguin",
    project_urls={
        "Documentation": "https://github.com/espitiaandres/penguin",
        "Source": "https://github.com/espitiaandres/penguin",
        "Tracker": "https://github.com/espitiaandres/penguin/issues",
    },
)
